<?php
/**
 * This file contains functions and hooks for styling Hootkit plugin
 *   Hootkit is a free plugin released under GPL license and hosted on wordpress.org.
 *   It is recommended to the user via wp-admin using TGMPA class
 *
 * This file is loaded at 'after_setup_theme' action @priority 10 ONLY IF hootkit plugin is active
 *
 * @package    Unos BizDeck
 * @subpackage HootKit
 */

// Register HootKit
// Parent added @priority 5
add_filter( 'hootkit_register', 'unosbdeck_register_hootkit', 7 );

// Add dynamic CSS for hootkit
add_action( 'hoot_dynamic_cssrules', 'unosbdeck_hootkit_dynamic_cssrules', 8 );

/**
 * Register Hootkit
 * Parent added @priority 5
 *
 * @since 1.0
 * @param array $config
 * @return string
 */
if ( !function_exists( 'unosbdeck_register_hootkit' ) ) :
function unosbdeck_register_hootkit( $config ) {
	// Array of configuration settings.
	if ( isset( $config['supports'] ) && is_array( $config['supports'] ) )
		$config['supports'][] = 'widget-subtitle';
	return $config;
}
endif;

add_action( 'wp_enqueue_scripts', 'unosbdeck_enqueue_hootkit', 15 );
if ( !function_exists( 'unosbdeck_enqueue_hootkit' ) ) :
function unosbdeck_enqueue_hootkit() {

	// Backward compatibility // @deprecated < Unos2.9.16 @7.21
	if ( !function_exists( 'unos_enqueue_childhootkit' ) ) {
	/* 'unos-hootkit' is loaded using 'hoot_locate_style' which loads child theme location. Hence deregister it and load files again */
	wp_deregister_style( 'unos-hootkit' );
	/* Load Hootkit Style - Add dependency so that hotkit is loaded after */
	if ( file_exists( hoot_data()->template_dir . 'hootkit/hootkit.css' ) )
	wp_enqueue_style( 'unos-hootkit', hoot_data()->template_uri . 'hootkit/hootkit.css', array( 'hoot-style' ), hoot_data()->template_version );
	if ( file_exists( hoot_data()->child_dir . 'hootkit/hootkit.css' ) )
	wp_enqueue_style( 'unosbdeck-hootkit', hoot_data()->child_uri . 'hootkit/hootkit.css', array( 'hoot-style', 'unos-hootkit' ), hoot_data()->childtheme_version );
	}

}
endif;

add_filter( 'hoot_style_builder_inline_style_handle', 'unosbdeck_dynamic_css_hootkit_handle', 8 );
if ( !function_exists( 'unosbdeck_dynamic_css_hootkit_handle' ) ) :
function unosbdeck_dynamic_css_hootkit_handle( $handle ) {
	// Backward compatibility // @deprecated < Unos2.9.16 @7.21
	if ( !function_exists( 'unos_dynamic_css_childhootkit_handle' ) )
	return 'unosbdeck-hootkit';
	else return $handle;
}
endif;

/**
 * Custom CSS built from user theme options for hootkit features
 *
 * @since 1.0
 * @access public
 */
if ( !function_exists( 'unosbdeck_hootkit_dynamic_cssrules' ) ) :
function unosbdeck_hootkit_dynamic_cssrules() {

	global $hoot_style_builder;

	// Get user based style values
	$styles = unos_user_style();
	extract( $styles );

	$hoot_style_builder->remove( array(
		'.social-icons-icon',
		'#topbar .social-icons-icon, #page-wrapper .social-icons-icon',
	) );

	/*** Add Dynamic CSS ***/

	hoot_add_css_rule( array(
						'selector'  => '.content-block-subtitle',
						'property'  => 'color',
						'value'     => $accent_color,
						'idtag'     => 'accent_color'
					) );

	hoot_add_css_rule( array(
						'selector'  => '.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button',
						'property'  => array(
							'border-color' => array( $accent_color, 'accent_color' ),
							'background'   => array( $accent_color, 'accent_color' ),
							'color'        => array( $accent_font, 'accent_font' ),
							),
					) );
	hoot_add_css_rule( array(
						'selector'  => '.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button:hover, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button:hover',
						'property'  => array(
							'color'        => array( $accent_color, 'accent_color' ),
							'background'   => array( $accent_font, 'accent_font' ),
							),
					) );

}
endif;

/**
 * Modify Ticker default style
 *
 * @since 1.0
 * @param array $settings
 * @return string
 */
function unosbdeck_ticker_widget_settings( $settings ) {
	if ( isset( $settings['form_options']['thumbheight']['desc'] ) )
		$settings['form_options']['thumbheight']['desc'] = __( 'Default: 40 (recommended for single line style below).<br />Set this to 75 for multiline style below', 'unos-bizdeck' );
	return $settings;
}
function unosbdeck_ticker_products_widget_settings( $settings ) {
	if ( isset( $settings['form_options']['thumbheight']['desc'] ) )
		$settings['form_options']['thumbheight']['desc'] = __( 'Default: 75 (recommended for multi line style below).<br />Set this to 40 for single line style below', 'unos-bizdeck' );
	return $settings;
}
add_filter( 'hootkit_ticker_posts_widget_settings', 'unosbdeck_ticker_widget_settings', 5 );
add_filter( 'hootkit_products_ticker_widget_settings', 'unosbdeck_ticker_products_widget_settings', 5 );

/**
 * Modify Products Cart Icon default style
 *
 * @since 1.0
 * @param array $settings
 * @return string
 */
function unosmvu_products_carticon_widget_settings( $settings ) {
	if ( isset( $settings['form_options']['background'] ) )
		$settings['form_options']['background']['std'] = '#2269C1';
	if ( isset( $settings['form_options']['fontcolor'] ) )
		$settings['form_options']['fontcolor']['std'] = '#ffffff';
	return $settings;
}
add_filter( 'hootkit_products_carticon_widget_settings', 'unosmvu_products_carticon_widget_settings', 5 );

/**
 * Filter Ticker and Ticker Posts display Title markup
 *
 * @since 1.0
 * @param array $settings
 * @return string
 */
function unosbdeck_hootkit_widget_title( $display, $title, $context, $icon = '' ) {
	$display = '<div class="ticker-title accent-typo">' . $icon . $title . '</div>';
	return $display;
}
add_filter( 'hootkit_widget_ticker_title', 'unosbdeck_hootkit_widget_title', 5, 4 );