<?php


/* === Dynamic CSS === */


/* Update user based style values for premium dynamic css */
/**
 * Create user based style values for premium dynamic css
 * Priority@6: apply_filters -> base lite ; 5-> base prim
 *
 * @since 1.0
 * @access public
 * @return array
 */
function unosbdeck_user_style( $styles ){

	/* Override Base styles */

	/* Add child styles */
	$styles['background_color']           = hoot_get_mod( 'background_color', '#ffffff' ); // WordPress Custom Background
	$styles['headerfooter_bg']            = hoot_get_mod( 'headerfooter_bg' );
	$styles['headerfooter_font']          = hoot_get_mod( 'headerfooter_font' );
	$styles['body_fontface']              = hoot_get_mod( 'body_fontface' );
	$styles['subheadings_fontface']       = hoot_get_mod( 'subheadings_fontface' );
	$styles['subheadings_fontface_style'] = hoot_get_mod( 'subheadings_fontface_style' );

	return $styles;
}
add_filter( 'unos_user_style', 'unosbdeck_user_style', 6 );

/**
 * Custom CSS built from user theme options
 * For proper sanitization, always use functions from library/sanitization.php
 *
 * @since 1.0
 * @access public
 */
function unosbdeck_dynamic_cssrules() {

	global $hoot_style_builder;

	// Get user based style values
	$styles = unos_user_style();
	extract( $styles );

	hoot_add_css_rule( array(
						'selector'  => 'body',
						'property'  => 'border-color',
						'value'     => $accent_color,
						'idtag'     => 'accent_color',
					) );

	$bodyfontface = '';
	if ( 'fontds' == $body_fontface )
		$bodyfontface = '"Droid Sans", sans-serif';
	elseif ( 'fontos' == $body_fontface )
		$bodyfontface = '"Open Sans", sans-serif';
	elseif ( 'fontcf' == $body_fontface )
		$bodyfontface = '"Comfortaa", sans-serif';
	elseif ( 'fontpo' == $body_fontface )
		$bodyfontface = '"Poppins", sans-serif';
	elseif ( 'fontow' == $body_fontface )
		$bodyfontface = '"Oswald", sans-serif';
	elseif ( 'fontim' == $body_fontface )
		$bodyfontface = 'Impact, Arial, sans-serif';
	elseif ( 'fontno' == $body_fontface )
		$bodyfontface = '"Noto Serif", serif';
	elseif ( 'fontsl' == $body_fontface )
		$bodyfontface = '"Slabo 27px", serif';
	elseif ( 'fontgr' == $body_fontface )
		$bodyfontface = 'Georgia, serif';
	hoot_add_css_rule( array(
						'selector'  => 'body' . ',' . '.enforce-body-font' . ',' . '.site-title-body-font',
						'property'  => 'font-family',
						'value'     => $bodyfontface,
					) );

	$headingproperty = array();
	if ( 'fontds' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Droid Sans", sans-serif' );
	elseif ( 'fontos' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Open Sans", sans-serif' );
	elseif ( 'fontcf' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Comfortaa", sans-serif' );
	elseif ( 'fontpo' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Poppins", sans-serif' );
	elseif ( 'fontow' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Oswald", sans-serif' );
	elseif ( 'fontim' == $headings_fontface )
		$headingproperty['font-family'] = array( 'Impact, Arial, sans-serif' );
	elseif ( 'fontno' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Noto Serif", serif' );
	elseif ( 'fontsl' == $headings_fontface )
		$headingproperty['font-family'] = array( '"Slabo 27px", serif' );
	elseif ( 'fontgr' == $headings_fontface )
		$headingproperty['font-family'] = array( 'Georgia, serif' );
	if ( 'uppercase' == $headings_fontface_style )
		$headingproperty['text-transform'] = array( 'uppercase' );
	else
		$headingproperty['text-transform'] = array( 'none' );
	if ( !empty( $headingproperty ) ) {
		hoot_add_css_rule( array(
						'selector'  => 'h1, h2, h3, h4, h5, h6, .title, .titlefont',
						'property'  => $headingproperty,
					) );
		hoot_add_css_rule( array(
						'selector'  => '.sidebar .widget-title, .sub-footer .widget-title, .footer .widget-title',
						'property'  => $headingproperty,
					) );
		hoot_add_css_rule( array(
						'selector'  => '.post-gridunit-title, .hk-gridunit-title', // @deprecated <= HootKit v1.1.3 @9.20 postgrid=>grid-widget postslist=>list-widget
						'property'  => $headingproperty,
					) );
	}

	$subheadingproperty = array();
	if ( 'fontds' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Droid Sans", sans-serif' );
	elseif ( 'fontos' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Open Sans", sans-serif' );
	elseif ( 'fontcf' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Comfortaa", sans-serif' );
	elseif ( 'fontpo' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Poppins", sans-serif' );
	elseif ( 'fontow' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Oswald", sans-serif' );
	elseif ( 'fontim' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( 'Impact, Arial, sans-serif' );
	elseif ( 'fontno' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Noto Serif", serif' );
	elseif ( 'fontsl' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( '"Slabo 27px", serif' );
	elseif ( 'fontgr' == $subheadings_fontface )
		$subheadingproperty['font-family'] = array( 'Georgia, serif' );
	if ( 'uppercase' == $subheadings_fontface_style || 'uppercasei' == $subheadings_fontface_style )
		$subheadingproperty['text-transform'] = array( 'uppercase' );
	else
		$subheadingproperty['text-transform'] = array( 'none' );
	if ( 'standardi' == $subheadings_fontface_style || 'uppercasei' == $subheadings_fontface_style )
		$subheadingproperty['font-style'] = array( 'italic' );
	else
		$subheadingproperty['font-style'] = array( 'normal' );
	if ( !empty( $subheadingproperty ) ) {
		hoot_add_css_rule( array(
						'selector'  => '.hoot-subtitle, .entry-byline, .post-gridunit-subtitle .entry-byline, .hk-gridunit-subtitle .entry-byline, .posts-listunit-subtitle .entry-byline, .hk-listunit-subtitle .entry-byline, .content-block-subtitle .entry-byline', // @deprecated <= HootKit v1.1.3 @9.20 postgrid=>grid-widget postslist=>list-widget
						'property'  => $subheadingproperty,
					) );
	}

	hoot_add_css_rule( array(
						'selector'  => '#topbar',
						'property'  => array(
							'background' => array( 'none' ),    // $accent_color
							'color'      => array( 'inherit' ), // $accent_font
							),
					) );

	hoot_add_css_rule( array(
						'selector'  => '#topbar.js-search .searchform.expand .searchtext',
						'property'  => 'background',
						'value'     => $content_bg_color,
					) );
	hoot_add_css_rule( array(
						'selector'  => '#topbar.js-search .searchform.expand .searchtext' . ',' . '#topbar .js-search-placeholder',
						'property'  => 'color',
						'value'     => 'inherit',
					) );
		hoot_add_css_rule( array(
						'selector'  => '#header' . ',' . '#header-primary .js-search .searchform.expand .searchtext',
						'property'  => 'background',
						'value'     => $headerfooter_bg,
					) );
		hoot_add_css_rule( array(
						'selector'  => '#header-primary .js-search .searchform.expand .searchtext' . ',' . '#header-primary .js-search-placeholder',
						'property'  => 'color',
						'value'     => $headerfooter_font,
					) );

	hoot_add_css_rule( array(
						'selector'         => '#site-title' . ',' . '#site-logo.accent-typo #site-title' . ',' . '#site-logo.invert-accent-typo #site-title', // Let logo typography options take effect even when inside accent bg
						'property'  => 'color',
						'value'     => $headerfooter_font,
					) );

	hoot_add_css_rule( array(
						'selector'  => '#site-description' . ',' . '#site-logo.accent-typo #site-description' . ',' . '#site-logo.invert-accent-typo #site-description', // Let logo typography options take effect even when inside accent bg
						'property'  => 'color',
						'value'     => $headerfooter_font,
					) );
		hoot_add_css_rule( array(
						'selector'  => '.menu-side-box.js-search .searchform.expand .searchtext',
						'property'  => 'background',
						'value'     => $headerfooter_bg,
					) );
		hoot_add_css_rule( array(
						'selector'  => '.menu-side-box.js-search .searchform.expand .searchtext' . ',' . '.menu-side-box .js-search-placeholder',
						'property'  => 'color',
						'value'     => $headerfooter_font,
					) );
	hoot_add_css_rule( array(
						'selector'         => '.menu-items > li > a' . ',' . '.menu-toggle' . ',' . '.menu-side-box', // .menu-side-box instead of div.menu-side-box so that font-size still remains small-font()
						'property'         => 'color',
						'value'            => $headerfooter_font,
					) );
	hoot_add_css_rule( array(
						'selector'         => '.menu-items ul a' . ',' . '.mobilemenu-fixed .menu-toggle',
						'property'         => 'color',
						'value'            => $headerfooter_font,
					) );
	hoot_add_css_rule( array(
						'selector'  => '.menu-items ul',
						'property'  => array(
							'background'   => array( $headerfooter_bg ),
							),
					) );
	hoot_add_css_rule( array(
						'selector'         => '.menu-items > li > a',
						'property'         => 'color',
						'value'            => $headerfooter_font,
						'media'            => 'only screen and (max-width: 969px)',
					) );
	hoot_add_css_rule( array(
						'selector'  => '.mobilemenu-fixed .menu-toggle, .mobilemenu-fixed .menu-items' . ',' . '.menu-items',
						'property'  => array(
							'background'   => array( $headerfooter_bg ),
							),
						'media'     => 'only screen and (max-width: 969px)',
					) );


	hoot_add_css_rule( array(
						'selector'  => '.sub-footer',
						'property'  => array(
							'background'   => array( $headerfooter_bg ),
							'color'        => array( $headerfooter_font ),
							),
					) );

	hoot_add_css_rule( array(
						'selector'  => '.footer', // '.sub-footer' . ',' . '.footer',
						'property'  => array(
							'background'   => array( $headerfooter_bg ),
							'color'        => array( $headerfooter_font ),
							),
					) );

	hoot_add_css_rule( array(
						'selector'  => '.footer h1, .footer h2, .footer h3, .footer h4, .footer h5, .footer h6, .footer .title',
						'property'  => 'color',
						'value'     => $headerfooter_font,
					) );

	hoot_add_css_rule( array(
						'selector'         => '.sub-footer .widget-title, .footer .widget-title',
						'property'  => 'color',
						'value'     => $headerfooter_font,
					) );

	hoot_add_css_rule( array(
						'selector'  => '.post-footer',
						'property'  => array(
							'background'   => array( $headerfooter_bg ),
							'color'        => array( $headerfooter_font ),
							),
					) );

	$headerbgshadow = ( hoot_color( $headerfooter_bg, 'isdark', null ) ) ? 'inset 0px -3px 3px 0px rgba(255, 255, 255, 0.05)' : 'inset 0px -3px 3px 0px rgba(0, 0, 0, 0.10)';
	hoot_add_css_rule( array(
					'selector'  => '#header-supplementary:first-child, #header-primary:not(:last-child)',
					'property'  => 'box-shadow',
					'value'     => $headerbgshadow,
				) );
	if ( hoot_color( $headerfooter_bg, 'isdark', null ) ) {
		hoot_add_css_rule( array(
						'selector'  => 'div .menu-items ul li',
						'property'  => 'background',
						'value'     => 'rgba(255, 255, 255, 0.08)',
					) );
	}
	if ( hoot_color( $headerfooter_bg, 'isdark', null ) ) {
		hoot_add_css_rule( array(
						'selector'  => 'div .menu-items ul',
						'property'  => 'border-color',
						'value'     => 'rgba(255, 255, 255, 0.15)',
					) );
	}
	hoot_add_css_rule( array(
						'selector'  => '.menu-items > li.current-menu-item:not(.nohighlight):after, .menu-items > li.current-menu-ancestor:after, .menu-items > li:hover:after' . ',' . '.menu-hoottag',
						'property'  => 'border-color',
						'value'     => $headerfooter_font,
					) );

	$logoproperty = array();
	if ( 'fontds' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Droid Sans", sans-serif' );
	elseif ( 'fontos' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Open Sans", sans-serif' );
	elseif ( 'fontcf' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Comfortaa", sans-serif' );
	elseif ( 'fontpo' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Poppins", sans-serif' );
	elseif ( 'fontow' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Oswald", sans-serif' );
	elseif ( 'fontim' == $logo_fontface )
		$logoproperty['font-family'] = array( 'Impact, Arial, sans-serif' );
	elseif ( 'fontno' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Noto Serif", serif' );
	elseif ( 'fontsl' == $logo_fontface )
		$logoproperty['font-family'] = array( '"Slabo 27px", serif' );
	elseif ( 'fontgr' == $logo_fontface )
		$logoproperty['font-family'] = array( 'Georgia, serif' );
	if ( 'uppercase' == $logo_fontface_style )
		$logoproperty['text-transform'] = array( 'uppercase' );
	else
		$logoproperty['text-transform'] = array( 'none' );
	if ( !empty( $logoproperty ) ) {
		hoot_add_css_rule( array(
						'selector'  => '#site-title',
						'property'  => $logoproperty,
					) );
	}

	$sitetitleheadingfont = '';
	if ( 'fontds' == $headings_fontface )
		$sitetitleheadingfont = '"Droid Sans", sans-serif';
	elseif ( 'fontos' == $headings_fontface )
		$sitetitleheadingfont = '"Open Sans", sans-serif';
	elseif ( 'fontcf' == $headings_fontface )
		$sitetitleheadingfont = '"Comfortaa", sans-serif';
	elseif ( 'fontpo' == $headings_fontface )
		$sitetitleheadingfont = '"Poppins", sans-serif';
	elseif ( 'fontow' == $headings_fontface )
		$sitetitleheadingfont = '"Oswald", sans-serif';
	elseif ( 'fontim' == $headings_fontface )
		$sitetitleheadingfont = 'Impact, Arial, sans-serif';
	elseif ( 'fontno' == $headings_fontface )
		$sitetitleheadingfont = '"Noto Serif", serif';
	elseif ( 'fontsl' == $headings_fontface )
		$sitetitleheadingfont = '"Slabo 27px", serif';
	elseif ( 'fontgr' == $headings_fontface )
		$sitetitleheadingfont = 'Georgia, serif';
	hoot_add_css_rule( array(
						'selector'  => '.site-title-heading-font',
						'property'  => 'font-family',
						'value'     => $sitetitleheadingfont,
					) );
	hoot_add_css_rule( array(
						'selector'  => '.entry-grid .more-link',
						'property'  => 'font-family',
						'value'     => $sitetitleheadingfont,
					) );

	$hoot_style_builder->remove( array(
		// Unos < 2.9.15
		'.menu-items li.current-menu-item, .menu-items li.current-menu-ancestor, .menu-items li:hover',
		'.menu-items li.current-menu-item > a, .menu-items li.current-menu-ancestor > a, .menu-items li:hover > a',
		// Unos >= 2.9.15
		'.menu-items li.current-menu-item:not(.nohighlight), .menu-items li.current-menu-ancestor, .menu-items li:hover',
		'.menu-items li.current-menu-item:not(.nohighlight) > a, .menu-items li.current-menu-ancestor > a, .menu-items li:hover > a',
	) );
	hoot_add_css_rule( array(
						'selector'  => '.menu-items ul li.current-menu-item:not(.nohighlight), .menu-items ul li.current-menu-ancestor, .menu-items ul li:hover',
						'property'  => 'background',
						'value'     => $accent_color,
						'idtag'     => 'accent_color'
					) );
	hoot_add_css_rule( array(
						'selector'  => '.menu-items ul li.current-menu-item:not(.nohighlight) > a, .menu-items ul li.current-menu-ancestor > a, .menu-items ul li:hover > a',
						'property'  => 'color',
						'value'     => $accent_font,
						'idtag'     => 'accent_font'
					) );

	$halfwidgetmargin = false;
	if ( intval( $widgetmargin ) )
		$halfwidgetmargin = ( intval( $widgetmargin ) / 2 > 25 ) ? ( intval( $widgetmargin ) / 2 ) . 'px' : '25px';
	if ( $halfwidgetmargin )
		hoot_add_css_rule( array(
						'selector'  => '.main > .main-content-grid:first-child' . ',' . '.content-frontpage > .frontpage-area-boxed:first-child',
						'property'  => 'margin-top',
						'value'     => $halfwidgetmargin,
					) );

	hoot_add_css_rule( array(
						'selector'  => '.widget_newsletterwidget, .widget_newsletterwidgetminimal',
						'property'  => array(
							// property  => array( value, idtag, important, typography_reset ),
							'background' => array( $accent_color, 'accent_color' ),
							'color'      => array( $accent_font, 'accent_font' ),
							),
					) );

}
add_action( 'hoot_dynamic_cssrules', 'unosbdeck_dynamic_cssrules', 3 );