<?php


/* === Customizer Options === */


/**
 * Update theme defaults
 * Prim @priority 5
 * Prim child @priority 9
 *
 * @since 1.0
 * @access public
 * @return array
 */
if ( !function_exists( 'unosbdeck_default_style' ) ) :
function unosbdeck_default_style( $defaults ){
	$defaults = array_merge( $defaults, array(
		'accent_color'         => '#2269C1',
		'accent_font'          => '#ffffff',
		'widgetmargin'         => 35,
		'logo_fontface'        => 'fontow',
		'headings_fontface'    => 'fontds',
	) );
	return $defaults;
}
endif;
add_filter( 'unos_default_style', 'unosbdeck_default_style', 7 );

/**
 * Add Options (settings, sections and panels) to Hoot_Customize class options object
 *
 * Parent Lite/Prim add options using 'init' hook both at priority 0. Currently there is no way
 * to hook in between them. Hence we hook in later at 5 to be able to remove options if needed.
 * The only drawback is that options involving widget areas cannot be modified/created/removed as
 * those have already been used during widgets_init hooked into init at priority 1. For adding options
 * involving widget areas, we can alterntely hook into 'after_setup_theme' before lite/prim options
 * are built. Modifying/removing such options from lite/prim still needs testing.
 *
 * @since 1.0
 * @access public
 */
if ( !function_exists( 'unosbdeck_add_customizer_options' ) ) :
function unosbdeck_add_customizer_options() {

	$hoot_customize = Hoot_Customize::get_instance();

	// Modify Options
	$hoot_customize->remove_settings( array( 'logo_tagline_size', 'logo_tagline_style' ) );
	$hoot_customize->remove_settings( 'pageheader_background_location' );

	// Define Options
	$options = array(
		'settings' => array(),
		'sections' => array(),
		'panels' => array(),
	);

	$options['settings']['headerfooter_bg'] = array(
		'label'       => esc_html__( 'Header/Footer Background', 'unos-bizdeck' ),
		'section'     => 'colors',
		'type'        => 'color',
		'default'     => '#272727',
		'priority'    => '188',
		'transport' => 'postMessage',
	);
	$options['settings']['headerfooter_font'] = array(
		'label'       => esc_html__( 'Header/Footer Font Color', 'unos-bizdeck' ),
		'section'     => 'colors',
		'type'        => 'color',
		'default'     => '#ffffff',
		'priority'    => '188',
		'transport' => 'postMessage',
	);

	$options['settings']['subheadings_fontface'] = array(
		'label'       => esc_html__( 'Sub Headings Font (Free Version)', 'unos-bizdeck' ),
		'section'     => 'typography',
		'type'        => 'select',
		'priority'    => 207, // Non static options must have a priority
		'choices'     => array( ),
		'default'     => 'fontgr',
	);

	$options['settings']['subheadings_fontface_style'] = array(
		'label'       => esc_html__( 'Sub Heading Font Style', 'unos-bizdeck' ),
		'section'     => 'typography',
		'type'        => 'select',
		'priority'    => 207, // Non static options must have a priority
		'choices'     => array(
			'standard'   => esc_html__( 'Standard', 'unos-bizdeck'),
			'standardi'  => esc_html__( 'Standard Italics', 'unos-bizdeck'),
			'uppercase'  => esc_html__( 'Uppercase', 'unos-bizdeck'),
			'uppercasei' => esc_html__( 'Uppercase Italics', 'unos-bizdeck'),
		),
		'default'     => 'standardi',
		'transport' => 'postMessage',
	);

	$options['settings']['body_fontface'] = array(
		'label'       => esc_html__( 'Body Font (Free Version)', 'unos-bizdeck' ),
		'section'     => 'typography',
		'type'        => 'select',
		'priority'    => 207, // Non static options must have a priority
		'choices'     => array( ),
		'default'     => 'fontds',
	);

	// Add Options
	$hoot_customize->add_options( apply_filters( 'unosbdeck_customizer_options', array(
		'settings' => $options['settings'],
		'sections' => $options['sections'],
		'panels' => $options['panels'],
		) ) );

}
endif;
add_action( 'init', 'unosbdeck_add_customizer_options', 5 );

/**
 * Modify Lite customizer options
 * Prim hooks in later at priority 9
 *
 * @since 1.0
 * @access public
 */
function unosbdeck_modify_customizer_options( $options ){

	if ( isset( $options['settings']['widgetmargin'] ) )
		$options['settings']['widgetmargin']['input_attrs']['placeholder'] = esc_html__( 'default: 35', 'unos-bizdeck' );
	if ( isset( $options['settings']['logo_size'] ) )
		$options['settings']['logo_size']['default'] = 'small';
	if ( isset( $options['settings']['logo_side'] ) )
		$options['settings']['logo_side']['default'] = 'widget-area';
	if ( isset( $options['settings']['fullwidth_menu_align'] ) )
		$options['settings']['fullwidth_menu_align']['default'] = 'left';
	if ( isset( $options['settings']['logo_custom'] ) )
		$options['settings']['logo_custom']['default'] = array(
			'line1'  => array( 'text' => wp_kses_post( __( '<mark>Unos</mark>', 'unos-bizdeck' ) ), 'size' => '15px', 'font' => 'standard' ),
			'line2'  => array( 'text' => wp_kses_post( __( '<em>Biz</em><b>Deck</b>', 'unos-bizdeck' ) ), 'size' => '45px' ),
		);
	if ( !empty( $options['settings']['logo_custom']['description'] ) )
		$options['settings']['logo_custom']['description'] = sprintf( esc_html__( 'Use &lt;b&gt; &lt;em&gt; and &lt;mark&gt; tags in "Line Text" fields below to emphasize different words. Example:%1$s%2$s&lt;b&gt;Unos&lt;/b&gt; &lt;em&gt;Biz&lt;/em&gt; &lt;mark&gt;Deck&lt;/mark&gt;%3$s', 'unos-bizdeck' ), '<br />', '<code>', '</code>' );
	if ( isset( $options['settings']['headings_fontface_style'] ) )
		$options['settings']['headings_fontface_style']['default'] = 'uppercase';
	return $options;
}
add_filter( 'unos_customizer_options', 'unosbdeck_modify_customizer_options', 7 );

/**
 * Modify customizer options before being added to Class options variable
 *
 * @since 1.0
 * @access public
 */
function unosbdeck_hoot_customize_add_settings( $settings ){
	$fontoptions = array( 'logo_fontface', 'headings_fontface', 'subheadings_fontface', 'body_fontface' );
	foreach ( $fontoptions as $key ) if ( !empty( $settings[ $key ] ) )
		$settings[ $key ]['choices'] = array(
			'fontds' => esc_html__( 'Standard Font 1 (Droid Sans)', 'unos-bizdeck'),
			'fontos' => esc_html__( 'Standard Font 2 (Open Sans)', 'unos-bizdeck'),
			'fontcf' => esc_html__( 'Alternate Font 1 (Comfortaa)', 'unos-bizdeck'),
			'fontpo' => esc_html__( 'Alternate Font 2 (Poppins)', 'unos-bizdeck'),
			'fontow' => esc_html__( 'Display Font 1 (Oswald)', 'unos-bizdeck'),
			'fontim' => esc_html__( 'Display Font 2 (Impact)', 'unos-bizdeck'),
			'fontno' => esc_html__( 'Heading Font 1 (Noto Serif)', 'unos-bizdeck'),
			'fontsl' => esc_html__( 'Heading Font 2 (Slabo)', 'unos-bizdeck'),
			'fontgr' => esc_html__( 'Heading Font 3 (Georgia)', 'unos-bizdeck'),
		);
	return $settings;
}
add_filter( 'hoot_customize_add_settings', 'unosbdeck_hoot_customize_add_settings' );

/**
 * Modify Customizer Link Section
 *
 * @since 1.0
 * @access public
 */
function unosbdeck_customizer_option_linksection( $lcontent ){
	if ( is_array( $lcontent ) ) {
		if ( !empty( $lcontent['demo'] ) )
			$lcontent['demo'] = str_replace( 'demo.wphoot.com/unos', 'demo.wphoot.com/unos-bizdeck', $lcontent['demo'] );
		if ( !empty( $lcontent['install'] ) )
			$lcontent['install'] = str_replace( 'wphoot.com/support/unos', 'wphoot.com/support/unos-bizdeck', $lcontent['install'] );
		if ( !empty( $lcontent['rateus'] ) )
			$lcontent['rateus'] = str_replace( 'wordpress.org/support/theme/unos', 'wordpress.org/support/theme/unos-bizdeck', $lcontent['rateus'] );
	}
	return $lcontent;
}
add_filter( 'unos_customizer_option_linksection', 'unosbdeck_customizer_option_linksection' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 *
 * @since 1.0
 * @return void
 */
function unosbdeck_customize_preview_js() {
	if ( file_exists( hoot_data()->child_dir . 'admin/customize-preview.js' ) )
		wp_enqueue_script( 'unosbdeck-customize-preview', hoot_data()->child_uri . 'admin/customize-preview.js', array( 'hoot-customize-preview', 'customize-preview' ), hoot_data()->childtheme_version, true );
}
add_action( 'customize_preview_init', 'unosbdeck_customize_preview_js', 12 );

/**
 * Add style tag to support dynamic css via postMessage script in customizer preview
 *
 * @since 1.0
 * @access public
 */

function unosbdeck_customize_dynamic_selectors( $settings ) {
	if ( !is_array( $settings ) ) return $settings;
	$hootpload = ( function_exists( 'hoot_lib_premium_core' ) ) ? 1 : '';

	$modify = array(
		'box_background_color' => array(
			'color'			=> array( 'remove' => array(), 'add' => array(), ),
			'background'	=> array( 'remove' => array(), 'add' => array(), ),
		),
		'accent_color' => array(
			'color' => array(
				'remove' => array(
				),
				'add' => array(
					'.menu-items ul li.current-menu-item, .menu-items ul li.current-menu-ancestor, .menu-items ul li:hover',
					'.content-block-subtitle',
					'.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button:hover, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button:hover',
				),
			),
			'background' => array(
				'add' => array(
					'.widget_newsletterwidget, .widget_newsletterwidgetminimal',
					'.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button',
				),
				'remove' => array(
					'.menu-items li.current-menu-item, .menu-items li.current-menu-ancestor, .menu-items li:hover',
					'.social-icons-icon',
				),
			),
			'border-color' => array(
				'add' => array(
					'body',
					'.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button',
				),
			),
		),
		'accent_font' => array(
			'color' => array(
				'add' => array(
					'.widget_newsletterwidget, .widget_newsletterwidgetminimal',
					'.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button',
				),
				'remove' => array(
					'.menu-items li.current-menu-item > a, .menu-items li.current-menu-ancestor > a, .menu-items li:hover > a',
					'#topbar .social-icons-icon, #page-wrapper .social-icons-icon',
				),
			),
			'background' => array(
				'remove' => array(
				),
				'add' => array(
					'.menu-items ul li.current-menu-item > a, .menu-items ul li.current-menu-ancestor > a, .menu-items ul li:hover > a',
					'.slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-light-on-dark a.hootkitslide-button:hover, .slider-alt-caption .widget_hootkit-slider-image .lightSlider .wrap-dark-on-light a.hootkitslide-button:hover',
				),
			),
		),
	);

	if ( !$hootpload ) {
		array_push( $modify['accent_color']['background']['remove'], '#topbar', '#topbar.js-search .searchform.expand .searchtext' );
		array_push( $modify['accent_font']['color']['remove'], '#topbar', '#topbar.js-search .searchform.expand .searchtext', '#topbar .js-search-placeholder' );
		$modify['headings_fontface_style']['text-transform']['add'] = array(
			'.sidebar .widget-title, .sub-footer .widget-title, .footer .widget-title',
			'.post-gridunit-title, .hk-gridunit-title', // @deprecated <= HootKit v1.1.3 @9.20 postgrid=>grid-widget postslist=>list-widget
		);
	}

	foreach ( $modify as $id => $props ) {
		foreach ( $props as $prop => $ops ) {
			foreach ( $ops as $op => $values ) {
				if ( $op == 'remove' ) {
					foreach ( $values as $val ) {
						$akey = array_search( $val, $settings[$id][$prop] );
						if ( $akey !== false ) unset( $settings[$id][$prop][$akey] );
					}
				} elseif ( $op == 'add' ) {
					foreach ( $values as $val ) {
						$settings[$id][$prop][] = $val;
					}
				}
			}
		}
	}

	if ( !$hootpload ) {
		$settings['subheadings_fontface_style'] = array(
			'font-style'=> array( '.hoot-subtitle, .entry-byline, .post-gridunit-subtitle .entry-byline, .hk-gridunit-subtitle .entry-byline, .posts-listunit-subtitle .entry-byline, .hk-listunit-subtitle .entry-byline, .content-block-subtitle .entry-byline' ), // @deprecated <= HootKit v1.1.3 @9.20 postgrid=>grid-widget postslist=>list-widget
		);
		$settings['subheadings_fontface_style_trans'] = array(
			'text-transform'=> array( '.hoot-subtitle, .entry-byline, .post-gridunit-subtitle .entry-byline, .hk-gridunit-subtitle .entry-byline, .posts-listunit-subtitle .entry-byline, .hk-listunit-subtitle .entry-byline, .content-block-subtitle .entry-byline' ), // @deprecated <= HootKit v1.1.3 @9.20 postgrid=>grid-widget postslist=>list-widget
		);

		$settings['headerfooter_bg'] = array(
			'background'	=> array( '#header' . ',' . '#header-primary .js-search .searchform.expand .searchtext',
									  '.menu-side-box.js-search .searchform.expand .searchtext',
									  '.menu-items ul',
									  '.sub-footer',
									  '.footer',
									  '.post-footer',
									),
			'media'			=> array(
				'@media only screen and (max-width: 969px)' => array(
					'background'	=> array( '.mobilemenu-fixed .menu-toggle, .mobilemenu-fixed .menu-items' . ',' . '.menu-items', ),
				),
			),
		);
		$settings['headerfooter_font'] = array(
			'color'			=> array( '#header-primary .js-search .searchform.expand .searchtext' . ',' . '#header-primary .js-search-placeholder',
									  '#site-title' . ',' . '#site-logo.accent-typo #site-title' . ',' . '#site-logo.invert-accent-typo #site-title',
									  '#site-description' . ',' . '#site-logo.accent-typo #site-description' . ',' . '#site-logo.invert-accent-typo #site-description',
									  '.menu-side-box.js-search .searchform.expand .searchtext' . ',' . '.menu-side-box .js-search-placeholder',
									  '.menu-items > li > a' . ',' . '.menu-toggle' . ',' . '.menu-side-box',
									  '.menu-items ul a' . ',' . '.mobilemenu-fixed .menu-toggle',
									  '.sub-footer',
									  '.footer',
									  '.footer h1, .footer h2, .footer h3, .footer h4, .footer h5, .footer h6, .footer .title',
									  '.sub-footer .widget-title, .footer .widget-title',
									  '.post-footer',
									),
			'border-color'	=> array( '.menu-items > li.current-menu-item:not(.nohighlight):after, .menu-items > li.current-menu-ancestor:after, .menu-items > li:hover:after' . ',' . '.menu-hoottag',
									),
			'media'			=> array(
				'@media only screen and (max-width: 969px)' => array(
					'color'			=> array( '.menu-items > li > a', ),
				),
			),
		);
	}

	return $settings;
}
add_filter( 'hoot_customize_dynamic_selectors', 'unosbdeck_customize_dynamic_selectors', 5 );